/**
 * Configuration for head elements added during the creation of index.html.
 *
 * All href attributes are added the publicPath (if exists) by default.
 * You can explicitly hint to prefix a publicPath by setting a boolean value to a key that has
 * the same name as the attribute you want to operate on, but prefix with =
 *
 * Example:
 * { name: 'msapplication-TileImage', content: '/assets/icon/ms-icon-144x144.png', '=content': true },
 * Will prefix the publicPath to content.
 *
 * { rel: 'apple-touch-icon', sizes: '57x57', href: '/assets/icon/apple-icon-57x57.png', '=href': false },
 * Will not prefix the publicPath on href (href attributes are added by default
 *
 */
module.exports = {
  link: [
    /**
     * <link> tags for 'apple-touch-icon' (AKA Web Clips).
     */
    { rel: 'icon', sizes: '72x72', href: '/assets/icons/icon-72x72.png' },
    { rel: 'icon', sizes: '96x96', href: '/assets/icons/icon-96x96.png' },
    { rel: 'icon', sizes: '128x128', href: '/assets/icons/icon-128x128.png' },
    { rel: 'icon', sizes: '144x144', href: '/assets/icons/icon-144x144.png' },
    { rel: 'icon', sizes: '152x152', href: '/assets/icons/icon-152x152.png' },
    { rel: 'icon', sizes: '384x384', href: '/assets/icons/icon-384x384.png' },
    { rel: 'icon', sizes: '512x512', href: '/assets/icons/icon-512x512.png' },
    /**
     * <link> tags for android web app icons
     */
    { rel: 'icon', type: 'image/png', sizes: '192x192', href: '/assets/icons/icon-192x192.png' },

    /**
     * <link> tags for favicons
     */
    { rel: 'icon', type: 'image/png', sizes: '96x96', href: '/assets/icons/icon-96x96.png' },

    /**
     * <link> tags for a Web App Manifest
     */
    { rel: 'manifest', href: '/assets/manifest.json' }
  ],
  meta: [
    { name: 'icon', content: '#00bcd4' },
    { name: 'icon', content: '/assets/icons/icon-144x144.png', '=content': true },
    { name: 'theme-color', content: '#00bcd4' }
  ]
};
